@@ -2,7 +2,7 @@
 
 from __future__ import unicode_literals
 
-__version__ = '3.1.0'
+__version__ = '3.1.1'
 
 __all__ = [
     # constants
@@ -81,7 +81,8 @@ class LDIFWriter(object):
         self._base64_attrs = lower(base64_attrs)
         self._cols = cols
         self._line_sep = line_sep
-        self.records_written = 0
+
+        self.records_written = 0  #: number of records that have been written
 
     def _fold_line(self, line):
         """Write string line as one or more folded lines."""
@@ -228,9 +229,9 @@ class LDIFParser(object):
         self._line_sep = line_sep
         self._strict = strict
 
-        self.line_counter = 0
-        self.byte_counter = 0
-        self.records_read = 0
+        self.line_counter = 0  #: number of lines that have been read
+        self.byte_counter = 0  #: number of bytes that have been read
+        self.records_read = 0  #: number of records that have been read
 
     def _iter_unfolded_lines(self):
         """Iter input unfoled lines. Skip comments."""
@@ -268,20 +269,17 @@ class LDIFParser(object):
         """Parse a single attribute type/value pair."""
         colon_pos = line.index(b':')
         attr_type = line[0:colon_pos]
-        value_spec = line[colon_pos:colon_pos + 2]
-        if value_spec == b': ':
-            attr_value = line[colon_pos + 2:].lstrip()
-        elif value_spec == b'::':
+        if line[colon_pos:].startswith(b'::'):
             attr_value = base64.decodestring(line[colon_pos + 2:])
-        elif value_spec == b':<':
+        elif line[colon_pos:].startswith(b':<'):
             url = line[colon_pos + 2:].strip()
             attr_value = b''
             if self._process_url_schemes:
                 u = urlparse(url)
                 if u[0] in self._process_url_schemes:
                     attr_value = urlopen(url.decode('ascii')).read()
-        elif value_spec == b':\r\n' or value_spec == b'\n':
-            attr_value = b''
+        else:
+            attr_value = line[colon_pos + 1:].strip()
         return attr_type.decode('utf8'), attr_value.decode('utf8')
 
     def _error(self, msg):
