@@ -46,6 +46,14 @@ objectclass: person
 
 """
 
+BYTES_EMPTY_ATTR_VALUE = b"""dn: uid=foo123,dc=ws1,dc=webhosting,o=eim
+uid: foo123
+domainname: foo.bar
+homeDirectory: /foo/bar.local
+aliases:
+aliases: foo.bar
+"""
+
 LINES = [
     b'version: 1',
     b'dn: cn=Alice Alison,mail=alicealison@example.com',
@@ -179,7 +187,7 @@ class TestLDIFParser(unittest.TestCase):
         with mock.patch('ldif3.log.warning') as warning:
             self.p._strict = False
             fn()
-            warning.assert_called()
+            assert warning.called
 
     def test_check_dn_not_none(self):
         self._test_error(lambda:
@@ -235,6 +243,20 @@ class TestLDIFParser(unittest.TestCase):
             self.assertEqual(record, RECORDS[i])
 
 
+class TestLDIFParserEmptyAttrValue(unittest.TestCase):
+    def setUp(self):
+        self.stream = BytesIO(BYTES_EMPTY_ATTR_VALUE)
+        self.p = ldif3.LDIFParser(self.stream)
+
+    def test_parse(self):
+        list(self.p.parse())
+
+    def test_parse_value(self):
+        dn, record = list(self.p.parse())[0]
+
+        self.assertEqual(record['aliases'], ['', 'foo.bar'])
+
+
 class TestLDIFWriter(unittest.TestCase):
     def setUp(self):
         self.stream = BytesIO()
